diff --git a/migrate_tools.module b/migrate_tools.module
index 553d739..b4fc208 100644
--- a/migrate_tools.module
+++ b/migrate_tools.module
@@ -9,8 +9,6 @@
  * Implements hook_entity_type_alter().
  */
 function migrate_tools_entity_type_alter(array &$entity_types) {
-  return;
-  // @todo: UI must be redone for 8.1.x.
   // Inject our UI into the general migration and migration group config entities.
   /** @var \Drupal\Core\Config\Entity\ConfigEntityType[] $entity_types */
   $entity_types['migration']
diff --git a/src/Controller/MigrationListBuilder.php b/src/Controller/MigrationListBuilder.php
index f9f07d7..6dad96e 100644
--- a/src/Controller/MigrationListBuilder.php
+++ b/src/Controller/MigrationListBuilder.php
@@ -12,6 +12,8 @@ use Drupal\Core\Entity\EntityInterface;
 use Drupal\Core\Entity\EntityStorageInterface;
 use Drupal\Core\Entity\EntityTypeInterface;
 use Drupal\Core\Routing\CurrentRouteMatch;
+use Drupal\migrate\Plugin\Migration;
+use Drupal\migrate_plus\Plugin\MigrationConfigEntityPluginManager;
 use Drupal\Core\Url;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 use Drupal\Core\Datetime\DateFormatter;
@@ -26,11 +28,20 @@ use Drupal\Core\Datetime\DateFormatter;
 class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHandlerInterface {
 
   /**
+   * Default object for current_route_match service.
+   *
    * @var \Drupal\Core\Routing\CurrentRouteMatch
    */
   protected $currentRouteMatch;
 
   /**
+   * Plugin manager for migration plugins.
+   *
+   * @var \Drupal\migrate_plus\Plugin\MigrationConfigEntityPluginManager
+   */
+  protected $migrationConfigEntityPluginManager;
+
+  /**
    * Constructs a new EntityListBuilder object.
    *
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
@@ -40,9 +51,10 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
    * @param \Drupal\Core\Routing\CurrentRouteMatch $current_route_match
    *   The Current route match service.
    */
-  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, CurrentRouteMatch $current_route_match) {
+  public function __construct(EntityTypeInterface $entity_type, EntityStorageInterface $storage, CurrentRouteMatch $current_route_match, MigrationConfigEntityPluginManager $migration_config_entity_plugin_manager) {
     parent::__construct($entity_type, $storage);
     $this->currentRouteMatch = $current_route_match;
+    $this->migrationConfigEntityPluginManager = $migration_config_entity_plugin_manager;
   }
 
   /**
@@ -52,7 +64,8 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
     return new static(
       $entity_type,
       $container->get('entity.manager')->getStorage($entity_type->id()),
-      $container->get('current_route_match')
+      $container->get('current_route_match'),
+      $container->get('plugin.manager.config_entity_migration')
     );
   }
 
@@ -77,22 +90,22 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
   }
 
   /**
    * Builds a row for an entity in the entity listing.
    *
    * @param \Drupal\migrate\Entity\EntityInterface $migration
    *   The entity for which to build the row.
    *
    * @return array
    *   A render array of the table row for displaying the entity.
    *
    * @see Drupal\Core\Entity\EntityListController::render()
    */
-  public function buildRow(EntityInterface $migration) {
+  public function buildRow(Migration $migration) {
     $row['label'] = $migration->label();
     $row['machine_name'] = $migration->id();
     $row['status'] = $migration->getStatusLabel();
 
-    // Derive the stats
+    // Derive the stats.
     $source_plugin = $migration->getSourcePlugin();
     $row['total'] = $source_plugin->count();
     $map = $migration->getIdMap();
@@ -105,32 +118,32 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
     else {
       $row['unprocessed'] = $row['total'] - $map->processedCount();
     }
-    $migration_group = $migration->getThirdPartySetting('migrate_plus', 'migration_group');
-    if (!$migration_group) {
-      $migration_group = 'default';
-    }
-    $route_parameters = array(
-      'migration_group' => $migration_group,
-      'migration' => $migration->id()
-    );
-    $row['messages'] = array(
-      'data' => array(
-        '#type' => 'link',
-        '#title' => $map->messageCount(),
-        '#url' => Url::fromRoute("migrate_tools.messages", $route_parameters),
-      ),
-    );
-    $migrate_last_imported_store = \Drupal::keyValue('migrate_last_imported');
-    $last_imported =  $migrate_last_imported_store->get($migration->id(), FALSE);
-    if ($last_imported) {
+    //$migration_group = $migration->getThirdPartySetting('migrate_plus', 'migration_group');
+    //if (!$migration_group) {
+      //$migration_group = 'default';
+    //}
+    //$route_parameters = array(
+      //'migration_group' => $migration_group,
+      //'migration' => $migration->id()
+    //);
+    //$row['messages'] = array(
+      //'data' => array(
+        //'#type' => 'link',
+        //'#title' => $map->messageCount(),
+        //'#url' => Url::fromRoute("migrate_tools.messages", $route_parameters),
+      //),
+    //);
+    //$migrate_last_imported_store = \Drupal::keyValue('migrate_last_imported');
+    //$last_imported =  $migrate_last_imported_store->get($migration->id(), FALSE);
+    //if ($last_imported) {
       /** @var DateFormatter $date_formatter */
-      $date_formatter = \Drupal::service('date.formatter');
-      $row['last_imported'] = $date_formatter->format($last_imported / 1000,
-        'custom', 'Y-m-d H:i:s');
-    }
-    else {
-      $row['last_imported'] = '';
-    }
+      //$date_formatter = \Drupal::service('date.formatter');
+      //$row['last_imported'] = $date_formatter->format($last_imported / 1000,
+        //'custom', 'Y-m-d H:i:s');
+    //}
+    //else {
+      //$row['last_imported'] = '';
+    //}
     return $row; // + parent::buildRow($migration);
   }
 
@@ -138,33 +151,7 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
    * {@inheritdoc}
    */
   public function load() {
-    $entity_ids = $this->getEntityIds();
-    // We're already sorting the entities properly in loadMultiple, and
-    // ConfigEntityListBuilder's load() messes it up with an extra sort(). So,
-    // simply take the entities in the order loaded.
-    $entities = $this->storage->loadMultipleOverrideFree($entity_ids);
-    return $entities;
-  }
-
-  /**
-   * Retrieve the migrations belonging to the appropriate group.
-   *
-   * @return array
-   *   An array of entity IDs.
-   */
-  protected function getEntityIds() {
-    $query = $this->getStorage()->getQuery('OR');
-    $keys = $this->entityType->getKeys();
-    $migration_group = $this->currentRouteMatch->getParameter('migration_group');
-    // Add groupless migrations to the default group.
-    if ($migration_group == 'default') {
-      $query->notExists('third_party_settings.migrate_plus.migration_group');
-    }
-    return $query
-      ->condition('third_party_settings.migrate_plus.migration_group', $migration_group)
-      ->sort($keys['id'])
-      ->pager($this->limit)
-      ->execute();
+    return $this->migrationConfigEntityPluginManager->createInstances([]);
   }
 
   /**
@@ -77,22 +90,22 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
 
   /**
-   * Builds a row for an entity in the entity listing.
+   * Builds a row for a migration plugin.
    *
@@ -77,22 +90,22 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
    *
-   * @param \Drupal\migrate\Entity\EntityInterface $migration
-   *   The entity for which to build the row.
+   * @param \Drupal\migrate\Plugin\MigrationInterface $migration
+   *   The migration plugin for which to build the row.
    *
    * @return array
@@ -77,22 +90,22 @@ class MigrationListBuilder extends ConfigEntityListBuilder implements EntityHand
    *
    * @return array
-   *   A render array of the table row for displaying the entity.
+   *   A render array of the table row for displaying the plugin information.
    *
    * @see Drupal\Core\Entity\EntityListController::render()
